#!/usr/bin/env python3

import os
import sys
import json
import boto3
import logging
import time
from botocore.exceptions import ClientError
from botocore.config import Config


logging.basicConfig(
    level=logging.INFO,
    format="%(asctime)s [%(levelname)s] %(message)s",
    datefmt="%Y-%m-%dT%H:%M:%S%z",
)
logging.Formatter.converter = time.gmtime
logger = logging.getLogger()

endpoint_override = os.getenv("CB_LC_OVERRIDE_AWS_ENDPOINT_S3")
if endpoint_override:
    config = Config(s3={"addressing_style": "virtual"})
    s3 = boto3.client("s3", endpoint_url=f"https://{endpoint_override}", config=config)
    logger.info(f"Using S3 AWS API endpoint override of {endpoint_override}")
else:
    s3 = boto3.client("s3")

bucket = os.getenv("BUCKET_NAME")
if not bucket:
    logger.error("Missing BUCKET_NAME environment variable")
    sys.exit(1)

data_file = os.getenv("SEEDS_FILE")
if not data_file:
    logger.error("Missing SEEDS_FILE environment variable")

logger.info(f"Using bucket '{bucket}', loading seed data from '{data_file}'")

with open(data_file) as f:
    seeds = json.load(f)

for key, body in seeds.items():
    try:
        s3.head_object(Bucket=bucket, Key=key)
        logger.info(f"{key} already exists, skipping")
    except ClientError as e:
        if e.response["Error"]["Code"] == "404":
            logger.info(f"{key} missing, uploading")
            s3.put_object(
                Bucket=bucket, Key=key, ServerSideEncryption="AES256", Body=body
            )
        else:
            logger.error(e)

logger.info("S3 configuration files seeding completed")
